@@ -110,12 +110,7 @@ async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict
         'collection_address': collection_address,
         'index': x['index'],
         'content_url': content_url,
-        'metadata': {
-            'attributes': content.get('attributes'),
-            'description': content.get('description'),
-            'image': content.get('image'),
-            'name': content.get('name'),
-        },
+        'metadata': content,
         'owner': {
             'address': x['owner_address'].to_string()
         }
